@@ -24,7 +24,7 @@ class Math:
         return self.__text
 
     def __repr__(self):
-        return f"<rex_plus.Match object; span={self.span()}, match='{self.text()}'>"
+        return f"<rex_plus.Match object; span={self.span()}, text='{self.text()}'>"
 
 
 def search_all(pattern: str, s: str) -> List[Math]:
